Package: statease
Title: Simplified Statistical Analysis with Plain-English
        Interpretation
Version: 1.3.0
Authors@R: 
    person("Uwakmfon", "Paul", , "uwakmfon31@gmail.com", role = c("aut", "cre", "cph"))
Description: A toolkit for common statistical analyses including descriptive statistics, Student's t-tests (one-sample, independent, and paired), one-way and two-way Analysis of Variance (ANOVA), Multivariate Analysis of Variance (MANOVA), chi-square tests, Fisher's Exact Test, McNemar's Test, correlation analysis, simple and multiple linear regression, logistic regression, Friedman Test, and non-parametric tests (Mann-Whitney U, Wilcoxon Signed Rank, and Kruskal-Wallis). Additional tools include statistical power analysis and automated assumption checking. Each function automatically interprets results in plain English, reporting effect sizes, confidence intervals, and p-value interpretations. Post-hoc tests are automatically applied following significant results. A master function automatically detects the appropriate test based on the structure of the input data. Methods are based on Cohen, J. (1988) <doi:10.4324/9780203771587>, Tukey, J. W. (1949) <doi:10.2307/3001913>, and Shapiro and Wilk (1965) <doi:10.2307/2333709>.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/DevWebWacky/statease,
        https://devwebwacky.github.io/statease/
BugReports: https://github.com/DevWebWacky/statease/issues
Config/roxygen2/version: 8.0.0
Suggests: DT, shinydashboard, shinyjs, knitr, rmarkdown, testthat (>=
        3.0.0)
VignetteBuilder: knitr
Imports: car, pwr, shiny,
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-01 11:08:09 UTC; Wacky
Author: Uwakmfon Paul [aut, cre, cph]
Maintainer: Uwakmfon Paul <uwakmfon31@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-02 07:00:10 UTC
Built: R 4.4.3; ; 2026-07-02 09:28:08 UTC; unix
