Package: statease
Title: Simplified Statistical Analysis with Plain-English
        Interpretation
Version: 1.2.1
Authors@R: 
    person("Uwakmfon", "Paul", , "uwakmfon31@gmail.com", role = c("aut", "cre", "cph"))
Description: A toolkit for common statistical analyses including descriptive statistics, Student's t-tests (one-sample, independent, and paired), one-way and two-way Analysis of Variance (ANOVA), Multivariate Analysis of Variance (MANOVA), chi-square tests, correlation analysis, simple and multiple linear regression, logistic regression, and non-parametric tests (Mann-Whitney U, Wilcoxon Signed Rank, and Kruskal-Wallis). Each function automatically interprets results in plain English, reporting effect sizes, confidence intervals, and p-value interpretations. Post-hoc tests are automatically applied following significant results. A master function automatically detects the appropriate test based on the structure of the input data. Methods are based on Cohen, J. (1988) <doi:10.4324/9780203771587>, Tukey, J. W. (1949) <doi:10.2307/3001913>, and Shapiro and Wilk (1965) <doi:10.2307/2333709>.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/DevWebWacky/statease,
        https://devwebwacky.github.io/statease/
BugReports: https://github.com/DevWebWacky/statease/issues
Config/roxygen2/version: 8.0.0
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Imports: car
NeedsCompilation: no
Packaged: 2026-06-06 15:39:02 UTC; Wacky
Author: Uwakmfon Paul [aut, cre, cph]
Maintainer: Uwakmfon Paul <uwakmfon31@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-07 14:10:10 UTC
Built: R 4.6.0; ; 2026-06-07 17:21:23 UTC; unix
