# Generated by roxygen2: do not edit by hand

S3method(print,statease_anova)
S3method(print,statease_anova2)
S3method(print,statease_assumptions)
S3method(print,statease_chisq)
S3method(print,statease_cor)
S3method(print,statease_describe)
S3method(print,statease_fisher)
S3method(print,statease_friedman)
S3method(print,statease_kruskal)
S3method(print,statease_logistic)
S3method(print,statease_mannwhitney)
S3method(print,statease_manova)
S3method(print,statease_mcnemar)
S3method(print,statease_mlr)
S3method(print,statease_power)
S3method(print,statease_pvalue)
S3method(print,statease_reg)
S3method(print,statease_ttest)
S3method(print,statease_wilcoxon)
export(analyze)
export(anova2_interpret)
export(anova_interpret)
export(check_assumptions)
export(chisq_interpret)
export(cor_interpret)
export(describe)
export(fisher_interpret)
export(friedman_interpret)
export(interpret_p)
export(kruskal_interpret)
export(logistic_interpret)
export(mannwhitney_interpret)
export(manova_interpret)
export(mcnemar_interpret)
export(mlr_interpret)
export(power_interpret)
export(reg_interpret)
export(run_app)
export(ttest_interpret)
export(wilcoxon_interpret)
importFrom(stats,IQR)
importFrom(stats,TukeyHSD)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,bartlett.test)
importFrom(stats,binomial)
importFrom(stats,chisq.test)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,confint.default)
importFrom(stats,contr.sum)
importFrom(stats,cor.test)
importFrom(stats,fisher.test)
importFrom(stats,fitted)
importFrom(stats,friedman.test)
importFrom(stats,glm)
importFrom(stats,kruskal.test)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,manova)
importFrom(stats,mcnemar.test)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,summary.aov)
importFrom(stats,t.test)
importFrom(stats,var.test)
importFrom(stats,wilcox.test)
importFrom(utils,combn)
