% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chisq_interpret.R
\name{chisq_interpret}
\alias{chisq_interpret}
\title{Chi-Square Test with Plain-English Interpretation}
\usage{
chisq_interpret(x, y, correct = TRUE, conf.level = 0.95)
}
\arguments{
\item{x}{A factor or character vector (first categorical variable)}

\item{y}{A factor or character vector (second categorical variable)}

\item{correct}{Logical. Apply Yates continuity correction. Default TRUE.}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_chisq} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
Chi-Square Test with Plain-English Interpretation
}
\examples{
x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
y <- c("Male","Female","Male","Female","Male","Female","Male","Female","Male","Female")
result <- chisq_interpret(x, y)
print(result)
}
