% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nonparam_interpret.R
\name{kruskal_interpret}
\alias{kruskal_interpret}
\title{Kruskal-Wallis Test with Plain-English Interpretation}
\usage{
kruskal_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ group}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_kruskal} containing
test results and interpretation. Use \code{print()} to display
the formatted report.
}
\description{
Kruskal-Wallis Test with Plain-English Interpretation
}
\examples{
df <- data.frame(
  score = c(23,45,12,67,34,89,56,43,78,90,11,34),
  group = rep(c("A","B","C"), each = 4)
)
result <- kruskal_interpret(score ~ group, data = df)
print(result)
}
