% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcnemar_interpret.R
\name{mcnemar_interpret}
\alias{mcnemar_interpret}
\title{McNemar's Test with Plain-English Interpretation}
\usage{
mcnemar_interpret(x, y, conf.level = 0.95)
}
\arguments{
\item{x}{A factor or character vector (first measurement)}

\item{y}{A factor or character vector (second measurement)}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_mcnemar} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
McNemar's Test with Plain-English Interpretation
}
\examples{
x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
y <- c("No","No","Yes","Yes","No","Yes","Yes","No","Yes","No")
result <- mcnemar_interpret(x, y)
print(result)
}
