% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_assumptions.R
\name{check_assumptions}
\alias{check_assumptions}
\title{Check Statistical Assumptions Before Running a Test}
\usage{
check_assumptions(test, x = NULL, y = NULL, data = NULL, formula = NULL)
}
\arguments{
\item{test}{The test you plan to run. One of "ttest", "anova",
"anova2", "correlation", "regression".}

\item{x}{A numeric vector (required for most tests)}

\item{y}{A numeric vector, factor, or character group variable
(optional depending on test)}

\item{data}{A data frame (required for anova, anova2, regression)}

\item{formula}{A formula (required for anova, anova2, regression)}
}
\value{
An object of class \code{statease_assumptions} containing
assumption check results. Use \code{print()} to display the
formatted report.
}
\description{
Check Statistical Assumptions Before Running a Test
}
\examples{
x <- c(23, 45, 12, 67, 34, 89, 56, 43, 78, 90)
y <- c(19, 38, 22, 51, 29, 74, 44, 38, 65, 80)
result <- check_assumptions("ttest", x = x, y = y)
print(result)
}
