% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_app.R
\name{run_app}
\alias{run_app}
\title{Launch the statease Shiny App}
\usage{
run_app(...)
}
\arguments{
\item{...}{Additional arguments passed to shiny::runApp()}
}
\value{
Launches the Shiny app in your browser
}
\description{
Launches an interactive Shiny application for
running statistical analyses without writing any code.
}
\examples{
if(interactive()){
  run_app()
}
}
