% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/power_interpret.R
\name{power_interpret}
\alias{power_interpret}
\title{Power Analysis with Plain English Interpretation}
\usage{
power_interpret(
  test,
  effect_size,
  n = NULL,
  alpha = 0.05,
  power = 0.8,
  n_groups = 2,
  n_predictors = 1
)
}
\arguments{
\item{test}{The statistical test. One of "ttest.one",
"ttest.two", "ttest.paired", "anova", "correlation",
"chisq", "regression".}

\item{effect_size}{The expected effect size. Use Cohen's
conventions: small = 0.2, medium = 0.5, large = 0.8
for t-tests; small = 0.10, medium = 0.25, large = 0.40
for ANOVA; small = 0.10, medium = 0.30, large = 0.50
for correlation.}

\item{n}{Sample size per group. If provided, calculates
achieved power. If NULL, calculates required sample size.}

\item{alpha}{Significance level. Default 0.05.}

\item{power}{Desired power level. Default 0.80.}

\item{n_groups}{Number of groups (for ANOVA only). Default 2.}

\item{n_predictors}{Number of predictors (for regression only).
Default 1.}
}
\value{
An object of class \code{statease_power} containing
power analysis results and interpretation. Use \code{print()}
to display the formatted report.
}
\description{
Power Analysis with Plain English Interpretation
}
\examples{
# Calculate required sample size for independent t-test
result <- power_interpret("ttest.two", effect_size = 0.5)
print(result)

# Calculate achieved power for given sample size
result2 <- power_interpret("ttest.two", effect_size = 0.5, n = 30)
print(result2)
}
